<?php

namespace App\Http\Controllers;

use App\Bank;
use App\Company;
use App\BankWithdraw;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;

class BankWithdrawController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $company = Company::latest()->first();
        $banks = Bank::all();
        //$withdraws = BankWithdraw::all();
        $bank_id = $request->bank_id;
        $from = $request->get('from');
        $to = $request->get('to');
        if ($from || $to) {
            $withdraws = BankWithdraw::with('Bank')
                ->where('bank_id', $bank_id)
                ->whereBetween('created_at', array($from, $to))->paginate(20);
        } else {
            $withdraws = BankWithdraw::with('Bank')->paginate(20);
        }
        return view('bank-withdraw.index', compact('withdraws', 'banks', 'company'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $banks = Bank::all();
        return view('bank-withdraw.create', compact('banks'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'amount'  => 'required',
            'bank_id' => 'required',
            'created_at' => 'required',
        ]);
        $bw = new BankWithdraw();
        $bw->bank_id = $request->bank_id;
        $bw->amount = $request->amount;
        $bw->slip_no = $request->slip_no;
        $bw->created_at = $request->created_at;
        $bw->save();
        $bank = Bank::where('id', $bw->bank_id)->first();
        $previous_bl = $bank->current_balance;
        $new_bl = $bw->amount;
        $sum = $previous_bl - $new_bl;
        $bank->current_balance = $sum;
        $bank->after_wd_balance = $sum;
        $bank->save();

        Toastr::success('Withdraw Created ! :)', 'Success');
        return redirect()->route('admin.bank-withdraw.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\BankWithdraw  $bankWithdraw
     * @return \Illuminate\Http\Response
     */
    public function show(BankWithdraw $bankWithdraw)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\BankWithdraw  $bankWithdraw
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $withdraw = BankWithdraw::findOrFail($id);
        $banks = Bank::all();
        return view('bank-withdraw.edit', compact('withdraw', 'banks'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\BankWithdraw  $bankWithdraw
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'amount'  => 'required',
            'bank_id' => 'required',
            'created_at' => 'required',
        ]);

        $bw = BankWithdraw::findOrFail($id);
        $pre_bl = $bw->amount;
        //dd($pre_bl);
        $bw->bank_id = $request->bank_id;
        $bw->amount = $request->amount;
        $bw->slip_no = $request->slip_no;
        $bw->created_at = $request->created_at;
        $bw->save();

        $bank = Bank::where('id', $bw->bank_id)->first();
        // dd($bw->amount);
        if ($bw->amount >= $pre_bl) {
            $previous_bl = $bank->current_balance;

            $new_bl = $bw->amount;

            $sum = $new_bl - $pre_bl;

            $bank->current_balance = $previous_bl - $sum;

            $bank->after_wd_balance = $previous_bl - $sum;
            $bank->save();
        } else {

            $min = $pre_bl - $bw->amount;

            $previous_bl = $bank->current_balance;
            $bank->current_balance =  $previous_bl + $min;
            $bank->after_wd_balance = $previous_bl + $min;
            // dd($bank->current_balance);
            $bank->save();
        }

        Toastr::success('Withdraw Updated ! :)', 'Success');
        return redirect()->route('admin.bank-withdraw.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\BankWithdraw  $bankWithdraw
     * @return \Illuminate\Http\Response
     */
    public function destroy(BankWithdraw $bankWithdraw)
    {
        if ($bankWithdraw->delete()) {
            Toastr::success('Withdraw deleted successfully :)', 'Success');
            return redirect()->back();
        } else {
            Toastr::error('Something went wrong :(', 'Error');
            return redirect()->back();
        }
    }
}
