<?php

namespace App\Http\Controllers;

use App\Company;
use App\SaleDetail;
use App\Account;
use App\installment;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class CompanyController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $companies = Company::all();
        return view('company.index', compact('companies'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('company.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'company_name' => 'required',
            'company_email' => 'required',
            'mobile' => 'required',
            'address' => 'required',
            'logo' => 'required',
        ]);
        $picture = '';
        if ($request->hasFile('logo')) {
            $picture = Storage::disk('public')->put('logo', $request->file('logo'));
        }
        $company = new Company();
        $company->name = $request->company_name;
        $company->email = $request->company_email;
        $company->mobile = $request->mobile;
        $company->address = $request->address;
        $company->quote = $request->quote;
        $company->logo = $picture;

        $company->save();
        Toastr::success('Company Successfully Created :)', 'Success');
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function show(Company $company)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $company = Company::findOrFail($id);
        return view('company.edit', compact('company'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'company_name' => 'required',
            'company_email' => 'required',
            'mobile' => 'required',
            'address' => 'required',
            'logo' => 'required',
        ]);
        $company = Company::findOrFail($id);
        $picture = $company->logo;
        if ($request->hasFile('logo')) {
            $picture = Storage::disk('public')->put('logo', $request->file('logo'));
        }

        $company->name = $request->company_name;
        $company->email = $request->company_email;
        $company->mobile = $request->mobile;
        $company->address = $request->address;
        $company->quote = $request->quote;
        $company->logo = $picture;

        $company->save();
        Toastr::success('Company Successfully Updated :)', 'Success');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function destroy(Company $company)
    {
        if ($company->delete()) {
            Toastr::success('Company deleted successfully :)', 'Success');
            return redirect()->back();
        } else {
            Toastr::error('Something went wrong :(', 'Error');
            return redirect()->back();
        }
    }
    public function company_accounts()
    {
        // // $total1 = SaleDetail::sum('company_log');
        // // $total2 = installment::sum('company_log');
        // $total1_ref = SaleDetail::sum('refference_log');
        // $total2_ref = installment::sum('refference_log');
        // // $sum_of_company = $total1 + $total2;
        $sum_of_ref = Account::sum('reference_log');;
        $accont = Account::all();
        $sum_of_company = Account::sum('company_log');

        return view('company.accounts', compact('sum_of_company', 'accont', 'sum_of_ref'));
    }
}
