<?php

namespace App\Http\Controllers;

use App\Bank;
use App\BankWithdraw;
use App\Deposit;
use App\Company;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;

class DepositController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $company = Company::latest()->first();
        $banks = Bank::all();
        $bank_id = $request->bank_id;
        $from = $request->get('from');
        $to = $request->get('to');
        if ($from || $to) {
            $deposits = Deposit::with('Bank')
                ->where('bank_id', $bank_id)
                ->whereBetween('created_at', array($from, $to))->paginate(20);
        } else {
            $deposits = Deposit::with('Bank')->paginate(20);
        }
        return view('deposit.index', compact('deposits', 'company', 'banks'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $banks = Bank::all();

        return view('deposit.create', compact('banks'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'slip_no' => 'required',
            'bank_id' => 'required',
            'amount' => 'required',
            'created_at' => 'required',
        ]);
        $deposit = new Deposit();
        $deposit->slip_no = $request->slip_no;
        $deposit->bank_id = $request->bank_id;
        $deposit->amount = $request->amount;
        $deposit->created_at = $request->created_at;
        //$deposit->after_dp_balance = 12345;
        $deposit->save();
        $dp_id = $deposit->bank_id;

        $bank = Bank::where('id', $dp_id)->first();
        $previous_bl = $bank->current_balance;
        $new_bl = $deposit->amount;
        $sum = $previous_bl + $new_bl;

        $bank->current_balance = $sum;
        $bank->after_dp_balance = $sum;
        $bank->save();

        Toastr::success('Deposit Created ! :)', 'Success');

        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Deposit  $deposit
     * @return \Illuminate\Http\Response
     */
    public function show(Deposit $deposit)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Deposit  $deposit
     * @return \Illuminate\Http\Response
     */
    public function edit(Deposit $deposit)
    {
        $banks = Bank::all();
        return view('deposit.edit', compact('banks', 'deposit'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Deposit  $deposit
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Deposit $deposit)
    {
        $request->validate([
            'slip_no' => 'required',
            'bank_id' => 'required',
            'amount' => 'required',
            'created_at' => 'required',
        ]);
        $pre_bl = $deposit->amount;
        $deposit->slip_no = $request->slip_no;
        $deposit->bank_id = $request->bank_id;
        $deposit->amount = $request->amount;
        $deposit->created_at = $request->created_at;
        // $deposit->after_dp_balance = 12345;
        $dp_id = $deposit->bank_id;

        $bank = Bank::where('id', $dp_id)->first();
        if ($deposit->amount >= $pre_bl) {
            $min = $deposit->amount - $pre_bl;
            $previous_bl = $bank->current_balance;
            $bank->current_balance = $min + $previous_bl;
            $bank->after_dp_balance = $min + $previous_bl;
            $bank->save();
        } else {
            $min = $pre_bl - $deposit->amount;
            $previous_bl = $bank->current_balance;
            $bank->current_balance =  $previous_bl - $min;
            $bank->after_dp_balance = $min - $previous_bl;
            $bank->save();
        }

        Toastr::success('Deposit Updated ! :)', 'Success');

        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Deposit  $deposit
     * @return \Illuminate\Http\Response
     */
    public function destroy(Deposit $deposit)
    {
        $deposit->delete();

        Toastr::success('Deposit Updated ! :)', 'Success');

        return redirect()->back();
    }
}
