<?php

namespace App\Http\Controllers;

use App\Company;
use App\Events\SendSMS;
use App\Http\Requests\CreateMemberRequest;
use App\Http\Requests\UpdateMemberRequest;
use App\Member;
use App\Reference;
use App\SubMemeber;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class MemberController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->get('query')) {
            $query = $request->get('query');
            $members = Member::where('name', 'like', '%' . $query . '%')
                ->orWhere('hus_father', 'like', '%' . $query . '%')
                ->orWhere('mother', 'like', '%' . $query . '%')
                ->orWhere('serial_id', 'like', '%' . $query . '%')
                ->orWhere('email', 'like', '%' . $query . '%')
                ->orWhere('mobile', 'like', '%' . $query . '%')
                ->orWhere('nid', 'like', '%' . $query . '%')
                ->paginate(20);
        } else {
            $members = Member::with('sales')->paginate(20);
        }
        return view('members.index', compact('members'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $references = Reference::all();

        return view('members.create', compact('references'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name'               => ["required", "array", "min:1", "max:3"],
            'hus_father'         => ["required", "array", "min:1", "max:3"],
            'mother'             => ["required", "array", "min:1", "max:3"],
            'email'              => ["required", "array", "min:1", "max:3"],
            'birthday'           => ["required", "array", "min:1", "max:3"],
            'nid'                => ["required", "array", "min:1", "max:3"],
            'profession'         => ["required", "array", "min:1", "max:3"],
            'religion'           => ["required", "array", "min:1", "max:3"],
            'nationality'        => ["required", "array", "min:1", "max:3"],
            'present_address'    => ["required", "array", "min:1", "max:3"],
            'permanent_address'  => ["required", "array", "min:1", "max:3"],
            'mobile'             => ["required", "array", "min:1", "max:3"],
            'member_id'          => 'required',
            'reference_id'       => 'required',
            'password'             => 'required'

        ]);

        $path = '';
        if ($request->hasFile('picture')) {
            $path = Storage::disk('public')->put('members', $request->file('picture'));
        }
        $member = new Member();

        foreach ($request->name as $key => $value) {
            if ($key === 0) {

                $member->name = $request->name[$key];
                $member->hus_father = $request->hus_father[$key];
                $member->nationality = $request->nationality[$key];
                $member->birthday = $request->birthday[$key];
                $member->mother = $request->mother[$key];
                $member->profession = $request->profession[$key];
                $member->religion = $request->religion[$key];
                $member->present_address = $request->present_address[$key];
                $member->permanent_address = $request->permanent_address[$key];
                $member->mobile = $request->mobile[$key];
                $member->email = $request->email[$key];
                $member->nid = $request->nid[$key];
                $member->picture = $path;
                $member->serial_id = $request->get('member_id');
                $member->reference_id = $request->reference_id;
                $member->password = $request->password;
                //dd($member);
                $member->save();
            }
            if ($key > 0) {
                $sub_member = new SubMemeber();
                $sub_member->name = $request->name[$key];
                $sub_member->member_id = $member->id;
                $sub_member->hus_father = $request->hus_father[$key];
                $sub_member->nationality = $request->nationality[$key];
                $sub_member->birthday = $request->birthday[$key];
                $sub_member->mother = $request->mother[$key];
                $sub_member->profession = $request->profession[$key];
                $sub_member->religion = $request->religion[$key];
                $sub_member->present_address = $request->present_address[$key];
                $sub_member->permanent_address = $request->permanent_address[$key];
                $sub_member->mobile = $request->mobile[$key];
                $sub_member->email = $request->email[$key];
                $sub_member->nid = $request->nid[$key];

                $sub_member->save();
            }
        }

        $to = $member->mobile;
        $message = "Dear" . $member->name . ", Thank For Joining With us. You have registered on our site.";

        event(new SendSMS($to, $message));

        Toastr::success('Member Successfully Created :)', 'Success');
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Member  $member
     * @return \Illuminate\Http\Response
     */

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Member  $member
     * @return \Illuminate\Http\Response
     */
    public function edit(Member $member)
    {
        return view('members.edit', compact('member'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Member  $member
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateMemberRequest $request, Member $member)
    {
        $picture = $member->picture;
        if ($request->hasFile('picture')) {
            $picture = Storage::disk('public')->put('members', $request->file('picture'));
        }
        $member->name = $request->get('name');
        $member->hus_father = $request->get('hus_father');
        $member->mother = $request->get('mother');
        $member->birthday = $request->get('birthday');
        $member->nid = $request->get('nid');
        $member->nationality = $request->get('nationality');
        $member->religion = $request->get('religion');
        $member->profession = $request->get('profession');
        $member->email = $request->get('email');
        $member->present_address = $request->get('present_address');
        $member->permanent_address = $request->get('permanent_address');
        $member->mobile = $request->get('mobile');
        $member->picture = $picture;
        $member->password = $request->get('password');

        if ($member->save()) {
            Toastr::success('Member updated successfully :)', 'Success');
            return redirect()->back();
        } else {
            Toastr::error('Something went wrong :(', 'Error');
            return redirect()->back();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Member  $member
     * @return \Illuminate\Http\Response
     */
    // public function delete_member(Member $member)
    // {

    //     //dd($member);
    //     if ($member->delete()) {

    //         Toastr::success('Member deleted successfully :)', 'Success');
    //         return redirect()->back();
    //     } else {
    //         Toastr::error('Something went wrong :(', 'Error');
    //         return redirect()->back();
    //     }
    // }

    public function delete_member($id)
    {
        //$member = Member::findOrFail($id);
        // dd($member);
        $member = new Member;
        $member = $member::find($id);

        $member->delete();
        Toastr::success('Member Deleted ! :)', 'Success');

        return redirect()->back();
    }
    public function profile()
    {
        $company = Company::latest()->first();
        $members = Member::get();

        //dd($member);
        return view('members.profile', compact('company', 'members'));
    }

    public function profileSearch(Request $request)
    {
        $company = Company::latest()->first();
        $member = Member::with(['sales', 'reference', 'installments', 'nominee'])->where('serial_id', $request->member_id)->first();
        if (!$member) {
            Toastr::error('No Member Found With This Member Id :(', 'Error');
            return redirect()->back();
        }
        $members = Member::get();
        return view('members.profile', compact('member', 'company', 'members'));
    }

    public function show(Member $member)
    {
        $company = Company::latest()->first();
        $member = Member::with(['subMembers', 'reference'])->where('id', $member->id)->first();
        // $member = Member::with(['sales', 'reference', 'installments', 'nominee'])->where('serial_id', $member->member_id)->first();

        //dd($member->member_id);
        return view('members.show', compact('member', 'company'));
    }
    public function print_type_one(request $member)
    {
        $company = Company::latest()->first();
        $member = Member::with(['subMembers', 'reference'])->where('id', $member->id)->first();
        // $member = Member::with(['sales', 'reference', 'installments', 'nominee'])->where('serial_id', $member->member_id)->first();
        //dd($member);
        return view('members.print_type_one', compact('member', 'company'));
    }
    public function print_type_two(request $member)
    {
        // dd("anika");
        $company = Company::latest()->first();
        $member = Member::with(['subMembers', 'reference'])->where('id', $member->id)->first();
        // $member = Member::with(['sales', 'reference', 'installments', 'nominee'])->where('serial_id', $member->member_id)->first();

        //dd($member->member_id);
        return view('members.print_type_two', compact('member', 'company'));
    }
}
