<?php

namespace App\Http\Controllers;

use App\Company;
use App\Plot;
use App\Block;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;

class PlotController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $query = $request->get('query');
        if ($query) {
            $plots = Plot::where('plot_size', 'like', '%' . $query . '%')
                ->orWhere('plot_size', 'like', '%' . $query . '%')
                ->orWhere('rate', 'like', '%' . $query . '%')
                ->orWhere('road', 'like', '%' . $query . '%')
                ->orWhere('block', 'like', '%' . $query . '%')
                ->orWhere('face', 'like', '%' . $query . '%')
                ->orWhere('quantity', 'like', '%' . $query . '%')
                ->paginate(20);
        } else {
            $plots = Plot::paginate(20);
        }
        $company = Company::latest()->first();
        return view('plot.index', compact('plots', 'company'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $blocks = Block::all();
        return view('plot.create', compact('blocks'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'plot_size' => 'required',
            'rate' => 'required',
            'road' => 'required',

            'face' => 'required',
            'quantity' => 'required',
        ]);

        $plot = new Plot();
        $plot->plot_size = $request->plot_size;
        $plot->rate = $request->rate;
        $plot->road = $request->road;
        $plot->block_id = $request->block_id;
        $plot->face = $request->face;
        $plot->quantity = $request->quantity;
        $b_id = $plot->block_id;

        $b_title = Block::where('id', $b_id)->first();

        $name = $b_title->title;

        $plot->block = $name;
        $plot->save();

        Toastr::success('Plot Created ! :)', 'Success');

        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Plot  $plot
     * @return \Illuminate\Http\Response
     */
    public function show(Plot $plot)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Plot  $plot
     * @return \Illuminate\Http\Response
     */
    public function edit(Plot $plot)
    {
        $blocks = Block::all();
        return view('plot.edit', compact('plot', 'blocks'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Plot  $plot
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Plot $plot)
    {
        $request->validate([
            'plot_size' => 'required',
            'rate' => 'required',
            'road' => 'required',

            'face' => 'required',
            'quantity' => 'required',
        ]);
        $plot->plot_size = $request->plot_size;
        $plot->rate = $request->rate;
        $plot->road = $request->road;
        $plot->block_id = $request->block_id;
        $plot->face = $request->face;
        $plot->quantity = $request->quantity;
        $b_id = $plot->block_id;
        $b_title = Block::where('id', $b_id)->first();

        $name = $b_title->title;

        $plot->block = $name;
        $plot->save();

        Toastr::success('Plot Updated ! :)', 'Success');

        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Plot  $plot
     * @return \Illuminate\Http\Response
     */
    public function destroy(Plot $plot)
    {
        $plot->delete();

        Toastr::success('Plot Updated ! :)', 'Success');

        return redirect()->back();
    }

    public function block_list(Request $request)
    {
        // $query = $request->get('query');
        // if ($query) {
        //     $blocks = Block::where('title', 'like', '%' . $query . '%')

        //         ->paginate(20);
        // } else {
        //     $blocks = Block::paginate(20);
        // }
        $company = Company::latest()->first();
        $blocks = Block::get();
        return view('plot.block_list', compact('blocks', 'company'));
    }
    public function add_block()
    {
        return view('plot.add_block');
    }

    public function store_block(Request $request)
    {
        $request->validate([
            'title'     => 'required',
            'katha'     => 'required',

        ]);
        $block = new Block();

        $block->title = $request->title;
        $block->katha = $request->katha;
        $block->booking_amount = 0;
        $block->installment_amount = 0;
        $block->ekkalin_amount = 0;
        $block->save();

        Toastr::success('Commision plan Successfully Created :)', 'Success');
        return redirect()->back();
    }

    public function edit_block($id)
    {
        $block =  Block::where('id', $id)->first();

        return view('plot.edit_block', compact('block'));
    }
    public function update_block(Request $request, $id)
    {
        $block = Block::where('id', $id)->first();


        $block->title = $request->title;
        $block->katha = $request->katha;
        $block->booking_amount = 0;
        $block->installment_amount = 0;
        $block->ekkalin_amount = 0;
        $block->save();

        Toastr::success('block updated successfully :)', 'Success');
        return redirect()->route('block_list');
    }

    public function delete_block($id)
    {
        $block = new Block;
        $block = $block::find($id);

        $block->delete();
        Toastr::success('Block Deleted ! :)', 'Success');

        return redirect()->back();
    }
}
