<?php

namespace App\Http\Controllers;

use App\Company;
use App\LandPurchase;
use App\purchaseInstallment;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;

class PurchaseInstallmentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $installments = purchaseInstallment::all();
        $company = Company::latest()->first();
        return view('purchase-installment.index', compact('installments', 'company'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        $purchase = LandPurchase::where('id', $request->purchase_id)->with('installments')->first();
        $paid = purchaseInstallment::sum('amount');
        return view('purchase-installment.create', compact('purchase', 'paid'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'amount'=>'required',
            'date'=>'required',
        ]);
        $purchase = LandPurchase::where('id', $request->purchase_id)->with('installments')->first();
        $paid = purchaseInstallment::sum('amount');

        if ($purchase->paid_amount + $request->amount + $paid > $purchase->deu_amount) {
            Toastr::error('Paid Amount is bigger than total amount :)' ,'Warning');
            return redirect()->back();
        } else {
            $installment = new purchaseInstallment();
            $installment->date = $request->date;
            $installment->amount = $request->amount;
            $installment->land_purchase_id = $request->purchase_id;
            $installment->save();

            Toastr::success('Installment Created Successfully :)' ,'Success');
            return redirect()->route('admin.purchase_installment.index');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\purchaseInstallment  $purchaseInstallment
     * @return \Illuminate\Http\Response
     */
    public function show(purchaseInstallment $purchaseInstallment)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\purchaseInstallment  $purchaseInstallment
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $installment = purchaseInstallment::findOrFail($id);
        return view('purchase-installment.edit', compact('installment'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\purchaseInstallment  $purchaseInstallment
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'amount'=>'required',
            'date'=>'required',
        ]);
        $installment = purchaseInstallment::where('id', $id)->first();
        $purchase = LandPurchase::where('id', $installment->land_purchase_id)->with('installments')->first();
        $paid = purchaseInstallment::where('land_purchase_id',$installment->land_purchase_id)->sum('amount');

        if ($purchase->paid_amount + $request->amount + $paid > $purchase->deu_amount) {
            Toastr::error('Paid Amount is bigger than total amount :)' ,'Warning');
            return redirect()->back();
        } else {
            $installment->date = $request->date;
            $installment->amount = $request->amount;
            $installment->save();

            Toastr::success('Installment Updated Successfully :)' ,'Success');
            return redirect()->route('admin.purchase_installment.index');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\purchaseInstallment  $purchaseInstallment
     * @return \Illuminate\Http\Response
     */
    public function destroy(purchaseInstallment $purchaseInstallment)
    {
        if ($purchaseInstallment->delete())
        {
            Toastr::success('Member deleted successfully :)' ,'Success');
            return redirect()->back();
        }
        else{
            Toastr::error('Something went wrong :(' ,'Error');
            return redirect()->back();
        }
    }
}
