<?php

namespace App\Http\Controllers;

use App\CommisionPlan;
use App\Reference;
use App\ReferenceWithdraw;
use App\SaleDetail;
use App\Block;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class ReferenceController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $query = $request->get('query');
        if ($query) {
            $references = Reference::where('name', 'like', '%' . $query . '%')
                ->orWhere('father_name', 'like', '%' . $query . '%')
                ->orWhere('mother_name', 'like', '%' . $query . '%')
                ->orWhere('nid', 'like', '%' . $query . '%')
                ->orWhere('email', 'like', '%' . $query . '%')
                ->orWhere('permanent_address', 'like', '%' . $query . '%')
                ->orWhere('present_address', 'like', '%' . $query . '%')
                ->orWhere('mobile', 'like', '%' . $query . '%')
                ->with(['referenceIncomes', 'withdraws'])
                ->paginate(20);
        } else {
            $references = Reference::with(['referenceIncomes', 'withdraws'])->paginate(20);
        }
        return view('reference.index', compact('references'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('reference.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'father_name' => 'required',
            'mother_name' => 'required',
            'nid' => 'required',
            'dob' => 'required',
            'email' => 'required',
            'profession' => 'required',
            'present_address' => 'required',
            'permanent_address' => 'required',
            'mobile' => 'required',
            'religion' => 'required',
            'image' => 'required',
            'password' => 'required'
        ]);

        $picture = '';
        if ($request->hasFile('image')) {
            $picture = Storage::disk('public')->put('members', $request->file('image'));
        }

        $reference = new Reference();

        $reference->name = $request->name;
        $reference->father_name = $request->father_name;
        $reference->mother_name = $request->mother_name;
        $reference->nid = $request->nid;
        $reference->dob = $request->dob;
        $reference->email = $request->email;
        $reference->profession = $request->profession;
        $reference->permanent_address = $request->permanent_address;
        $reference->present_address = $request->present_address;
        $reference->mobile = $request->mobile;
        $reference->religion = $request->religion;
        $reference->image = $picture;
        $reference->booking_amount = 0;
        $reference->installment_amount = 0;
        $reference->ekkalin_amount = 0;
        $reference->password = $request->password;
        $reference->save();

        Toastr::success('Reference successfully added ! :)', 'Success');

        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Reference  $reference
     * @return \Illuminate\Http\Response
     */
    public function show(Reference $reference)
    {
        return view('reference.show', compact('reference'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Reference  $reference
     * @return \Illuminate\Http\Response
     */
    public function edit(Reference $reference)
    {
        return view('reference.edit', compact('reference'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Reference  $reference
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Reference $reference)
    {
        $request->validate([
            'name' => 'required',
            'father_name' => 'required',
            'mother_name' => 'required',
            'nid' => 'required',
            'dob' => 'required',
            'email' => 'required',
            'profession' => 'required',
            'present_address' => 'required',
            'permanent_address' => 'required',
            'mobile' => 'required',
            'religion' => 'required'
        ]);

        $picture = $reference->image;
        if ($request->hasFile('image')) {
            $picture = Storage::disk('public')->put('members', $request->file('image'));
        }
        $reference->name = $request->name;
        $reference->father_name = $request->father_name;
        $reference->mother_name = $request->mother_name;
        $reference->nid = $request->nid;
        $reference->dob = $request->dob;
        $reference->email = $request->email;
        $reference->profession = $request->profession;
        $reference->permanent_address = $request->permanent_address;
        $reference->present_address = $request->present_address;
        $reference->mobile = $request->mobile;
        $reference->religion = $request->religion;
        $reference->image = $picture;
        $reference->booking_amount = 0;
        $reference->installment_amount = 0;
        $reference->ekkalin_amount = 0;
        $reference->password = $request->password;
        $reference->save();

        Toastr::success('Reference Updated ! :)', 'Success');

        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Reference  $reference
     * @return \Illuminate\Http\Response
     */
    public function destroy(Reference $reference)
    {
        $reference->delete();

        Toastr::success('Reference Updated ! :)', 'Success');

        return redirect()->back();
    }

    public function add_plan()
    {
        // dd('ss');
        $plans = CommisionPlan::get();

        //dd($plans);
        return view('plans.index', compact('plans'));
    }

    public function create_plan()
    {

        $references = Reference::all();
        $blocks = Block::all();
        //dd($block);
        return view('plans.create', compact('references', 'blocks'));
    }

    public function store_plan(Request $request)
    {
        $request->validate([
            'booking_amount'     => 'required',
            'installment_amount'     => 'required',
            'ekkalin_amount'     => 'required',

        ]);
        $plan = new CommisionPlan();

        $plan->booking_amount = $request->booking_amount;
        $plan->installment_amount = $request->installment_amount;
        $plan->ekkalin_amount = $request->ekkalin_amount;
        $plan->block_id = $request->block_id;

        $b_id = $plan->block_id;
        $b_title = Block::where('id', $b_id)->first();

        $name = $b_title->title;
        $katha_bl = $b_title->katha;
        $plan->block_title = $name;
        $plan->katha = $katha_bl;
        $plan->save();


        $bl = $plan->block_id;
        $blk = Block::where('id', $bl)->first();

        if ($blk->id ==  $plan->block_id) {
            $blk->booking_amount = $request->booking_amount;
            $blk->installment_amount = $request->installment_amount;
            $blk->ekkalin_amount = $request->ekkalin_amount;

            $blk->save();
        }
        Toastr::success('Commision plan Successfully Created :)', 'Success');
        return redirect()->back();
    }
    public function show_plan($id)
    {

        $blocks = Block::all();
        $plan = CommisionPlan::where('id', $id)->first();
        $ref = $plan->block_id;

        $block = Block::where('id', $ref)->first();

        return view('plans.show', compact('blocks', 'block', 'plan'));
    }
    public function edit_plan($id)
    {
        //dd('a');
        $blocks = Block::all();
        $plan = CommisionPlan::where('id', $id)->first();
        $ref = $plan->block_id;

        $block = Block::where('id', $ref)->first();
        //dd($blocks->id);
        return view('plans.edit', compact('blocks', 'block', 'plan'));
    }
    public function update_plan(Request $request, $id)
    {
        $plan = CommisionPlan::where('id', $id)->first();


        $plan->booking_amount = $request->booking_amount;
        $plan->installment_amount = $request->installment_amount;
        $plan->ekkalin_amount = $request->ekkalin_amount;
        $plan->block_id = $request->block_id;

        $b_id = $plan->block_id;
        $b_title = Block::where('id', $b_id)->first();

        $name = $b_title->title;

        $plan->block_title = $name;
        $plan->save();


        $bl = $plan->block_id;
        $blk = Block::where('id', $bl)->first();

        if ($blk->id ==  $plan->block_id) {
            $blk->booking_amount = $request->booking_amount;
            $blk->installment_amount = $request->installment_amount;
            $blk->ekkalin_amount = $request->ekkalin_amount;

            $blk->save();
        }
        if ($plan->save()) {
            Toastr::success('plan updated successfully :)', 'Success');
            return redirect()->route('add_plan');
        } else {
            Toastr::error('Something went wrong :(', 'Error');
            return redirect()->back();
        }
    }

    public function delete_plan($id)
    {
        $plan = new CommisionPlan;
        $plan = $plan::find($id);

        $plan->delete();
        Toastr::success('plan Deleted ! :)', 'Success');

        return redirect()->back();
    }
    public function create_withdraw()
    {
        $references = Reference::all();
        return view('admin-ref-withdraw.create', compact('references'));
    }
}
